<?php
// セッションを開始
session_start();

// POSTでデータが送られてこなかったら、contact.phpにリダイレクト
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: contact.php');
    exit;
}

// 入力値のサニタイズ
$postData = array_map('htmlspecialchars', $_POST);
$errorMessages = [];

// 氏名のバリデーション
if (empty($postData['name']) || mb_strlen($postData['name']) > 10) {
    $errorMessages['name'] = '氏名は必須項目です。10文字以内で入力してください。';
}

// フリガナのバリデーション
if (empty($postData['furigana']) || mb_strlen($postData['furigana']) > 10) {
    $errorMessages['furigana'] = 'フリガナは必須項目です。10文字以内で入力してください。';
}

// 電話番号のバリデーション
if (!preg_match('/^[0-9]{9,11}$/', $postData['phone'])) {
    $errorMessages['phone'] = '電話番号は0-9の数字で9〜11文字以内で入力してください。';
}

// メールアドレスのバリデーション
if (empty($postData['email']) || !filter_var($postData['email'], FILTER_VALIDATE_EMAIL)) {
    $errorMessages['email'] = 'メールアドレスは正しい形式で入力してください。';
}

// お問い合わせ内容のバリデーション
if (empty($postData['message'])) {
    $errorMessages['message'] = 'お問い合わせ内容は必須項目です。';
}

// エラーがある場合はcontact.phpにリダイレクト
if (!empty($errorMessages)) {
    $_SESSION['errors'] = $errorMessages;
    $_SESSION['post_data'] = $postData;
    header('Location: contact.php');
    exit;
}
?>
<!DOCTYPE html>
<html lang="ja">
<head>
    <meta charset="UTF-8">
    <title>お問い合わせ内容確認</title>
</head>
<body>
    <p>名前: <?php echo $postData['name']; ?></p>
    <p>フリガナ: <?php echo $postData['furigana']; ?></p>
    <p>電話番号: <?php echo $postData['phone']; ?></p>
    <p>メールアドレス: <?php echo $postData['email']; ?></p>
    <p>お問い合わせ内容: <?php echo nl2br($postData['message']); ?></p>

    <form action="complete.php" method="post">
        <input type="hidden" name="name" value="<?php echo $postData['name']; ?>">
        <input type="hidden" name="furigana" value="<?php echo $postData['furigana']; ?>">
        <input type="hidden" name="phone" value="<?php echo $postData['phone']; ?>">
        <input type="hidden" name="email" value="<?php echo $postData['email']; ?>">
        <input type="hidden" name="message" value="<?php echo $postData['message']; ?>">
        <input type="submit" value="送信">
    </form>
</body>
</html>


?>
